@@ -13,21 +13,24 @@ pub const ROCKET: [char; 2] = ['=', '>'];
 
 /// A piped expression.
 pub fn piped(tt: impl ToTokens) -> impl ToTokens {
-    from_fn(move |stream, span| {
-        stream.tokens(span, '|');
-        tt.to_tokens(stream, span);
-        stream.tokens(span, '|');
+    from_fn(move |stream| {
+        stream.write(('|', tt, '|'));
     })
 }
 
 pub fn as_mut(tt: impl ToTokens) -> impl ToTokens {
-    from_fn(move |stream, span| {
-        stream.tokens(span, ("Pin", S, "as_mut", parens(('&', "mut", tt))));
+    from_fn(move |stream| {
+        stream.write(("Pin", S, "as_mut", parens(('&', "mut", tt))));
     })
 }
 
-pub fn if_else(cond: impl ToTokens, then: impl ToTokens, else_: impl ToTokens) -> impl ToTokens {
-    ("if", cond, braced(then), "else", braced(else_))
+/// Generate an `if <cond> { <then> } else { <else_then> }` expression.
+pub fn if_else(
+    cond: impl ToTokens,
+    then: impl ToTokens,
+    else_then: impl ToTokens,
+) -> impl ToTokens {
+    ("if", cond, braced(then), "else", braced(else_then))
 }
 
 pub enum Option<T> {
@@ -41,8 +44,8 @@ where
 {
     fn to_tokens(self, stream: &mut TokenStream, span: Span) {
         match self {
-            Option::Some(tt) => stream.tokens(span, ("Option", S, "Some", parens(tt))),
-            Option::None => stream.tokens(span, ("Option", S, "None")),
+            Option::Some(tt) => stream.write(span, ("Option", S, "Some", parens(tt))),
+            Option::None => stream.write(span, ("Option", S, "None")),
         }
     }
 }
@@ -57,7 +60,7 @@ where
 {
     fn to_tokens(self, stream: &mut TokenStream, span: Span) {
         match self {
-            Poll::Ready(tt) => stream.tokens(span, ("Poll", S, "Ready", parens(tt))),
+            Poll::Ready(tt) => stream.write(span, ("Poll", S, "Ready", parens(tt))),
         }
     }
 }
